==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/FastStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { FastStochasticOscillatorIndicatorStrategy } from "./FastStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
var FastStochasticOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FastStochasticOscillatorIndicator, _super);
    function FastStochasticOscillatorIndicator() {
        var _this = _super.call(this) || this;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 10;
        _this.trendLinePeriod = 3;
        return _this;
    }
    FastStochasticOscillatorIndicator.prototype.get_up = function () {
        return new FastStochasticOscillatorIndicatorStrategy();
    };
    Object.defineProperty(FastStochasticOscillatorIndicator.prototype, "up", {
        get: function () {
            return this.get_up();
        },
        enumerable: false,
        configurable: true
    });
    FastStochasticOscillatorIndicator.prototype.get_u2 = function () {
        return FastStochasticOscillatorIndicator.$;
    };
    Object.defineProperty(FastStochasticOscillatorIndicator.prototype, "u2", {
        get: function () {
            return this.get_u2();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FastStochasticOscillatorIndicator.prototype, "va", {
        get: function () {
            return typeGetValue(this.c(FastStochasticOscillatorIndicator.vb));
        },
        set: function (a) {
            this.h(FastStochasticOscillatorIndicator.vb, a);
        },
        enumerable: false,
        configurable: true
    });
    FastStochasticOscillatorIndicator.prototype.uv = function () {
        return this.va;
    };
    FastStochasticOscillatorIndicator.prototype.u4 = function (a) {
        this.va = a;
    };
    FastStochasticOscillatorIndicator.$t = markType(FastStochasticOscillatorIndicator, 'FastStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    FastStochasticOscillatorIndicator.vb = StrategyBasedIndicator.u7(14, FastStochasticOscillatorIndicator.$);
    return FastStochasticOscillatorIndicator;
}(StrategyBasedIndicator));
export { FastStochasticOscillatorIndicator };

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/FastStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { FastStochasticOscillatorIndicatorStrategy } from "./FastStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
var FastStochasticOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FastStochasticOscillatorIndicator, _super);
    function FastStochasticOscillatorIndicator() {
        var _this = _super.call(this) || this;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 10;
        _this.trendLinePeriod = 3;
        return _this;
    }
    FastStochasticOscillatorIndicator.prototype.get_yy = function () {
        return new FastStochasticOscillatorIndicatorStrategy();
    };
    Object.defineProperty(FastStochasticOscillatorIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    FastStochasticOscillatorIndicator.prototype.get_zb = function () {
        return FastStochasticOscillatorIndicator.$;
    };
    Object.defineProperty(FastStochasticOscillatorIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FastStochasticOscillatorIndicator.prototype, "zj", {
        get: function () {
            return typeGetValue(this.c(FastStochasticOscillatorIndicator.zk));
        },
        set: function (a) {
            this.h(FastStochasticOscillatorIndicator.zk, a);
        },
        enumerable: false,
        configurable: true
    });
    FastStochasticOscillatorIndicator.prototype.y4 = function () {
        return this.zj;
    };
    FastStochasticOscillatorIndicator.prototype.zd = function (a) {
        this.zj = a;
    };
    FastStochasticOscillatorIndicator.$t = markType(FastStochasticOscillatorIndicator, 'FastStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    FastStochasticOscillatorIndicator.zk = StrategyBasedIndicator.zg(14, FastStochasticOscillatorIndicator.$);
    return FastStochasticOscillatorIndicator;
}(StrategyBasedIndicator));
export { FastStochasticOscillatorIndicator };
